Package 'bgev'

Title: Bimodal GEV Distribution with Location Parameter
Description: Description: Density, distribution function, quantile function random generation and estimation of bimodal GEV distribution given in Otiniano et al. (2023) <doi:10.1007/s10651-023-00566-7>. This new generalization of the well-known GEV (Generalized Extreme Value) distribution is useful for modeling heterogeneous bimodal data from different areas.
Authors: Cira Otiniano Author [aut], Yasmin Lirio Author [aut], Thiago Sousa Developer [cre]
Maintainer: Thiago Sousa Developer <[email protected]>
License: GPL (>=2)
Version: 0.3
Built: 2026-05-18 07:50:20 UTC
Source: https://github.com/thiagodoregosousa/bgev

Help Index